>From ac00af88a0d920c0a2526d71e84eae3ddbb40c8e Mon Sep 17 00:00:00 2001
From: Erik Van Grunderbeeck <erik@arawix.com>
Date: Tue, 22 Mar 2011 11:02:34 +0100
Subject: [PATCH 3/3] Add gettimeofday() to seperate file, if not compiling for windows not under mingw (its undefined otherwise).

Signed-off-by: Erik Van Grunderbeeck <erik@arawix.com>
---
 src/win32_time.c |   32 ++++++++++++++++++++++++++++++++
 1 files changed, 32 insertions(+), 0 deletions(-)
 create mode 100644 src/win32_time.c

diff --git a/src/win32_time.c b/src/win32_time.c
new file mode 100644
index 0000000..40239dd
--- /dev/null
+++ b/src/win32_time.c
@@ -0,0 +1,32 @@
+#include "windows.h"
+
+static unsigned __int64 offset_from_1601_to_1970 = 0;
+struct vm_timeval {
+	unsigned long tv_sec;
+	long int tv_usec;
+};
+
+int gettimeofday( struct vm_timeval *TP, struct vm_timezone *TZP ) {
+	/* FILETIME data structure is a 64-bit value representing the number
+	of 100-nanosecond intervals since January 1, 1601 */
+	unsigned __int64 tmb;
+	SYSTEMTIME bp;
+	if ( offset_from_1601_to_1970 == 0 ) {
+		/* prepare 1970 "epoch" offset */
+		bp.wDay = 1; bp.wDayOfWeek = 4; bp.wHour = 0;
+		bp.wMinute = 0; bp.wMilliseconds = 0;
+		bp.wMonth = 1; bp.wSecond = 0;
+		bp.wYear = 1970;
+		SystemTimeToFileTime(&bp, (FILETIME *)&offset_from_1601_to_1970);
+	}
+#ifndef _WIN32_WCE
+	GetSystemTimeAsFileTime((FILETIME *)&tmb);
+#else
+	GetSystemTime(&bp);
+	SystemTimeToFileTime(&bp, (FILETIME *)&tmb);
+#endif
+	tmb -= offset_from_1601_to_1970; /* 100 nsec ticks since 1 jan 1970 */
+	TP[0].tv_sec = (unsigned long)(tmb / 10000000); /* */
+	TP[0].tv_usec = (long)((tmb % 10000000) / 10); /* microseconds OK? */
+	return  (TZP != NULL) ? -1 : 0;
+}
\ No newline at end of file
-- 
1.7.0.2.msysgit.0

